@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.1   2011/04/01
+ * Version: 1.8.2+   2011/07/13
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -39,6 +39,9 @@ static void try_io(const char *policy, const char should_success)
 		char *cp = strchr(buffer, '\n');
 		if (cp)
 			*cp = '\0';
+		if (!strcmp(policy_file, proc_policy_exception_policy) &&
+		    !strncmp(buffer, "<kernel> ", 9))
+			memmove(buffer, buffer + 9, strlen(buffer + 9) + 1);
 		if (!strcmp(buffer, policy)) {
 			policy_found = 1;
 			break;
@@ -141,15 +144,13 @@ static void stage_policy_io_test(void)
 		try_io("path_group TEST3 boo/", 1);
 		try_io("address_group TEST 0.0.0.0", 1);
 		try_io("address_group TEST 0.0.0.0-1.2.3.4", 1);
-		try_io("address_group TEST 0:0:0:0:0:0:0:ff", 1);
-		try_io("address_group TEST "
-		       "0:0:0:0:0:0:0:0-ff:ff:ff:ff:ff:ff:ff:ff", 1);
+		try_io("address_group TEST ::ff", 1);
+		try_io("address_group TEST ::-ff:ff:ff:ff:ff:ff:ff:ff", 1);
 		try_io("address_group TEST "
 		       "fff0:fff1:fff2:fff3:fff4:fff5:fff6:fff7-"
 		       "fff8:fff9:fffa:fffb:fffc:fffd:fffe:ffff", 1);
-		try_io("address_group TEST2 0:0:0:0:0:0:0:ff", 1);
-		try_io("address_group TEST2 "
-		       "0:0:0:0:0:0:0:0-ff:ff:ff:ff:ff:ff:ff:ff", 1);
+		try_io("address_group TEST2 ::ff", 1);
+		try_io("address_group TEST2 ::-ff:ff:ff:ff:ff:ff:ff:ff", 1);
 		try_io("address_group TEST2 "
 		       "fff0:fff1:fff2:fff3:fff4:fff5:fff6:fff7-"
 		       "fff8:fff9:fffa:fffb:fffc:fffd:fffe:ffff", 1);
